'use strict';

function _cxLoadURL(url) {
        var iframe = document.createElement("iframe");
        iframe.setAttribute("src", encodeURI(url));
        iframe.setAttribute("width", "0px");
        iframe.setAttribute("height", "0px");
        iframe.setAttribute("style", "display:none;");
        iframe.setAttribute("frameborder", "0");
        document.body.appendChild(iframe);
        iframe.parentNode.removeChild(iframe);
        iframe = null;
};

var CreditXAgent = {

    _exec: function(funName, args) {
        var jsonStr = JSON.stringify(args);
        var url = "creditx://" + funName + "/" + jsonStr;
        _cxLoadURL(url);
    },

    pageNames: {
        register: 'REGISTER',
        login: 'LOGIN',
        idVerify: 'ID_VERIFY',
        operator: 'OPERATOR',
        biometricAuth: 'BIOMETRIC_AUTH',
        bindDebitCard: 'BIND_DEBIT_CARD',
        bindCreditCard: 'BIND_CREDIT_CARD',
        personalInfo: 'PERSONAL_INFO',
        contactsInfo: 'CONTACTS_INFO',
        loanIndex: 'LOAN_INDEX',
        loanSubmission: 'LOAN_SUBMISSION'
    },

    actionNames: {
        input: {
            registerUserID: 'INPUT_REGISTER_USER_ID',
            registerPassword: 'INPUT_REGISTER_PASSWORD',
            registerVerifyCode: 'INPUT_REGISTER_VERIFY_CODE',
            loginUserID: 'INPUT_LOGIN_USER_ID',
            loginPassword: 'INPUT_LOGIN_PASSWORD',
            loanIndexLoanAmount: 'INPUT_LOAN_INDEX_LOAN_AMOUNT',
            verifyIDName: 'INPUT_VERIFY_ID_NAME',
            verifyIdentity: 'INPUT_VERIFY_IDENTITY',
            operatorMobileNumber: 'INPUT_OPERATOR_MOBILE_NUMBER',
            operatorServicePassword: 'INPUT_OPERATOR_SERVICE_PASSWORD',
            bindDebitCardNumber: 'INPUT_BIND_DEBIT_CARD_NUMBER',
            bindDebitCardName: 'INPUT_BIND_DEBIT_CARD_NAME',
            bindDebitCardContactPhone: 'INPUT_BIND_DEBIT_CARD_CONTACT_PHONE',
            bindCreditCardNumber: 'INPUT_BIND_CREDIT_CARD_NUMBER',
            bindCreditCardName: 'INPUT_BIND_CREDIT_CARD_NAME',
            bindCreditCardContactPhone: 'INPUT_BIND_CREDIT_CARD_CONTACT_PHONE',
            personalHomeAddress: 'INPUT_PERSONAL_HOME_ADDRESS',
            personalHomePhone: 'INPUT_PERSONAL_HOME_PHONE',
            personalCompanyName: 'INPUT_PERSONAL_COMPANY_NAME',
            personalCompanyAddress: 'INPUT_PERSONAL_COMPANY_ADDRESS',
            personalJobTitle: 'INPUT_PERSONAL_JOB_TITLE',
            personalCompanyPhone: 'INPUT_PERSONAL_COMPANY_PHONE',
            contactInfoContact1Name: 'INPUT_CONTACT_INFO_CONTACT_1_NAME',
            contactInfoContact1Relation: 'INPUT_CONTACT_INFO_CONTACT_1_RELATION',
            contactInfoContact1Phone: 'INPUT_CONTACT_INFO_CONTACT_1_PHONE',
            contactInfoContact2Name: 'INPUT_CONTACT_INFO_CONTACT_2_NAME',
            contactInfoContact2Relation: 'INPUT_CONTACT_INFO_CONTACT_2_RELATION',
            contactInfoContact2Phone: 'INPUT_CONTACT_INFO_CONTACT_2_PHONE',
            loanSubmissionAmount: 'INPUT_LOAN_SUBMISSION_AMOUNT'
        },
        click: {
            registerGetVerifyCode: 'CLICK_REGISTER_GET_VERIFY_CODE',
            forgetPassword: 'CLICK_FORGET_PASSWORD',
            verifyIdPicFrnt: 'CLICK_VERIFY_ID_PIC_FRNT',
            verifyIdPicBak: 'CLICK_VERIFY_ID_PIC_BAK',
            verifyIdPicWithOwner: 'CLICK_VERIFY_ID_PIC_WITH_OWNER',
            loanIndexLoanClicked: 'CLICK_LOAN_INDEX_LOAN_CLICKED',
            personalSaveContacts: 'CLICK_PERSONAL_SAVE_CONTACTS',
            bindDebitCardSelectBank: 'CLICK_BIND_DEBIT_CARD_SELECT_BANK'
        },
        submit: {
            register: 'SUBMIT_REGISTER',
            login: 'SUBMIT_LOGIN',
            verifyIdPicWithOwner: 'SUBMIT_VERIFY_ID_PIC_WITH_OWNER',
            idVerify: 'SUBMIT_ID_VERIFY',
            operator: 'SUBMIT_OPERATOR',
            biometricAuth: 'SUBMIT_BIOMETRIC_AUTH',
            bindDebitCard: 'SUBMIT_BIND_DEBIT_CARD',
            bindCreditCard: 'SUBMIT_BIND_CREDIT_CARD',
            personalHomeInfo: 'SUBMIT_PERSONAL_HOME_INFO',
            personalCompanyInfo: 'SUBMIT_PERSONAL_COMPANY_INFO',
            personalContact1fromAddressBook: 'SUBMIT_PERSONAL_CONTACT_1_FROM_ADDRESS_BOOK',
            personalContact2fromAddressBook: 'SUBMIT_PERSONAL_CONTACT_2_FROM_ADDRESS_BOOK',
            loanSubmission: 'SUBMIT_LOAN_SUBMISSION'
        }
    },

    /**
     * 检测进入页面
     *
     * @param pageName 行为名称，参考 pageNames
     */
    onEnteringPage: function(pageName) {
        this._exec("onEnteringPage", [pageName]);
    },

    /**
     * 检测离开页面
     *
     * @param pageName 行为名称，参考 pageNames
     */
    onLeavingPage: function(pageName) {
        this._exec("onLeavingPage", [pageName]);
    },

    /**
     * 检测元素的点击行为
     *
     * @param actionName 行为名称，参考 actionNames.click
     */
    onClick: function(actionName){
        this._exec("onClick", [actionName]);
    },

    /**
     * 检测输入元素焦点变化
     *
     * @param actionName 行为名称，参考 actionNames.input
     * @param hasFocus   获得焦点
     */
    onInputFocusChange: function(actionName, hasFocus) {
        this._exec("onInputFocusChange", [actionName, hasFocus]);
    },

    /**
     * 检测输入元素内容变化
     *
     * @param actionName 行为名称，参考 actionNames.input
     * @param content    变化后的内容
     */
    onInputContentChanged: function(actionName, content) {
        this._exec("onInputContentChanged", [actionName, content]);
    },

    /**
     * 提交行为
     *
     * @param actionName   行为名称，参考 actionNames.submit
     * @param status       状态。 0：成功 1：失败
     * @param msg          成功或失败的描述
     */
    onSubmit: function(actionName, status, msg) {
        this._exec("onSubmit", [actionName,status,msg]);
    },

    /**
     * 为一个输入元素绑定相关事件监听
     *
     * @param actionName    行为名称，参考 actionNames.input
     * @param ele           HTML元素，必须为 INPUT或TEXTAREA元素
     */
    bindInputActions: function(actionName, ele) {
        if (ele.tagName != "INPUT" && ele.tagName != "TEXTAREA") {
            var msg = 'Unsupported input element \'' + ele.tagName + '\' for action ' + actionName;
            console.log("CreditXAgent: [WARNING]" + msg)
            this._exec("errorReport", [msg])
            return;
        }

        ele.onfocus = ()=>this.onInputFocusChange(actionName, true);
        ele.onblur = ()=>this.onInputFocusChange(actionName, false);
        ele.oninput = ()=>this.onInputContentChanged(actionName, ele.value);
    }
}